---
layout: page
title: "Documentation"
lang: en
---

Here you will find pointers to manuals, tutorials and references that
will come in handy when you feel like coding in Ruby.

### Getting Started

[Try Ruby!][1]
: An interactive tutorial that lets you try out Ruby right in your
  browser. This 15-minute tutorial is aimed at beginners who want to get
  a feeling of the language.

[Ruby Koans][2]
: The Koans walk you along the path to enlightenment in order to learn
  Ruby. The goal is to learn the Ruby language, syntax, structure, and
  some common functions and libraries. We also teach you culture.

[Hackety Hack][3]
: <q cite="http://hackety-hack.com/">The little coder’s starter kit</q>.
  A fun and easy way to learn about programming (through Ruby) using the
  Shoes GUI Toolkit.

[Why’s (Poignant) Guide to Ruby][4]
: An unconventional but interesting book that will teach you Ruby
  through stories, wit, and comics. Originally created by *why the lucky
  stiff*, this guide remains a classic for Ruby learners.

[Learn to Program][5]
: A wonderful little tutorial by Chris Pine for programming newbies. If
  you don’t know how to program, start here.

[Ruby in Twenty Minutes](/en/documentation/quickstart/)
: A nice tutorial covering the basics of Ruby. From start to finish it
  shouldn’t take you more than twenty minutes.

[Ruby from Other Languages](/en/documentation/ruby-from-other-languages/)
: Coming to Ruby from another language? Whether it’s C, C++, Java, Perl,
  PHP, or Python, this article has you covered!

[Learning Ruby][6]
: A thorough collection of Ruby study notes for those who are new to the
  language and in search of a solid introduction to Ruby’s concepts and
  constructs.

[Ruby Essentials][7]
: Ruby Essentials is a free on-line book designed to provide a concise
  and easy to follow guide to learning Ruby.

[Ruby &amp; Ruby on Rails programming tutorials][8]
: A site that aims to provide well-organized, rich content tutorials for
  both Ruby and Rails.

### Manuals

[Programming Ruby][9]
: The seminal work on Ruby in English, this first edition of the
  [Pragmatic Programmers’ book][10] is available for free online.

[Ruby User’s Guide][11]
: Translated from the original Japanese version written by Yukihiro
  Matsumoto (the creator of Ruby), this version, by Goto Kentaro and
  Mark Slagell is nice overview of many aspects of the Ruby language.

[The Ruby Programming Wikibook][12]
: A free online manual with beginner and intermediate content plus a
  thorough language reference.

### Reference Documentation

[Ruby Core Reference][13]
: Pulled straight from the source code using [RDoc][14], this reference
  work documents all of the core classes and modules (like String,
  Array, Symbol, etc…).

[Ruby Standard Library Reference][15]
: Also pulled from the source code using RDoc, this reference work
  documents the standard library.

[Ruby C API Reference][16]
: Documentation for Ruby’s underlying C code. Great if you want to write
  C extensions or contribute to Ruby’s development.

[RubyDoc.info][17]
: The one-stop web site for reference documentation about Ruby gems and
  GitHub-hosted Ruby projects.

[Rails Searchable API Doc][18]
: Rails and Ruby documentation with smart searching.

[APIdock][19]
: Ruby, Rails and RSpec documentation with users’ notes.

### Editors and IDEs

For coding in Ruby you can use the default editor of your operating
system. By the way, to be more effective in coding, it is worth to
choose a source code editor with basic Ruby support (e.g.
syntax-highlighting, file browsing) or an integrated development
environment with advanced features (e.g. code completion,refactoring,
testing support).

Here is a list of popular tools used by Rubyists:

* Linux and cross-platform tools:
  * [Aptana Studio][20]
  * [Emacs][21] with [Ruby mode][22] and [Rsense][23]
  * [Geany][24]
  * [gedit][25]
  * [Vim][26] with [vim-ruby][27] plugin and [Rsense][23]
  * [RubyMine][28]
  * [SciTe][29]

* On Windows:
  * [Notepad++][30]
  * [E-TextEditor][31]
  * [Ruby In Steel][32]

* On Mac OS X:
  * [TextMate][33]
  * [TextWrangler][34]

### Further Reading

[Ruby-Doc.org][35] maintains a comprehensive list of English
documentation sources. There are also plenty of [books about Ruby][36].
If you have questions about Ruby the [mailing
list](/en/community/mailing-lists/) is a great place to start.



[1]: http://tryruby.org/ 
[2]: http://rubykoans.com/ 
[3]: http://hackety-hack.com/ 
[4]: http://mislav.uniqpath.com/poignant-guide/ 
[5]: http://pine.fm/LearnToProgram/ 
[6]: http://rubylearning.com/ 
[7]: http://www.techotopia.com/index.php/Ruby_Essentials 
[8]: http://www.meshplex.org/wiki/Ruby/Ruby_on_Rails_programming_tutorials 
[9]: http://www.ruby-doc.org/docs/ProgrammingRuby/ 
[10]: http://pragmaticprogrammer.com/titles/ruby/index.html 
[11]: http://www.rubyist.net/~slagell/ruby/ 
[12]: http://en.wikibooks.org/wiki/Ruby_programming_language 
[13]: http://www.ruby-doc.org/core 
[14]: http://rdoc.sourceforge.net 
[15]: http://www.ruby-doc.org/stdlib 
[16]: http://www.ruby-doc.org/doxygen/current/ 
[17]: http://www.rubydoc.info/ 
[18]: http://railsapi.com/ 
[19]: http://apidock.com/ 
[20]: http://www.aptana.com/ 
[21]: http://www.gnu.org/software/emacs/ 
[22]: http://www.emacswiki.org/emacs/RubyMode 
[23]: http://cx4a.org/software/rsense/ 
[24]: http://www.geany.org/ 
[25]: http://projects.gnome.org/gedit/screenshots.html 
[26]: http://www.vim.org/ 
[27]: https://github.com/vim-ruby/vim-ruby 
[28]: http://www.jetbrains.com/ruby/ 
[29]: http://www.scintilla.org/SciTE.html 
[30]: http://notepad-plus-plus.org/ 
[31]: http://www.e-texteditor.com/ 
[32]: http://www.sapphiresteel.com/ 
[33]: http://macromates.com/ 
[34]: http://www.barebones.com/products/textwrangler/ 
[35]: http://ruby-doc.org 
[36]: http://www.ruby-doc.org/bookstore 
