---
layout: news_post
title: "DoS vulnerability in REXML"
lang: en
---

There is a DoS vulnerability in the REXML library included in the Ruby
Standard Library. A so-called \"XML entity explosion\" attack technique
can be used for remotely bringing down (disabling) any application which
parses user-provided XML using REXML.

Most Rails applications will be vulnerable because Rails parses
user-provided XML using REXML by default.

## 

An attacker can cause a denial of service by causing REXML to parse a
document containing recursively nested entities such as:

    <?xml version="1.0" encoding="UTF-8"?>
    <!DOCTYPE member [
      <!ENTITY a "&b;&b;&b;&b;&b;&b;&b;&b;&b;&b;">
      <!ENTITY b "&c;&c;&c;&c;&c;&c;&c;&c;&c;&c;">
      <!ENTITY c "&d;&d;&d;&d;&d;&d;&d;&d;&d;&d;">
      <!ENTITY d "&e;&e;&e;&e;&e;&e;&e;&e;&e;&e;">
      <!ENTITY e "&f;&f;&f;&f;&f;&f;&f;&f;&f;&f;">
      <!ENTITY f "&g;&g;&g;&g;&g;&g;&g;&g;&g;&g;">
      <!ENTITY g "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx">
    ]>
    <member>
    &a;
    </member>

## 

### 

* 1\.8.6-p287 and all prior versions
* 1\.8.7-p72 and all prior versions

### 

* all versions

## 

Please download the following monkey patch to fix this problem.

* [&lt;URL:http://www.ruby-lang.org/security/20080823rexml/rexml-expansion-fix2.rb&gt;][1]

Then fix your application to load rexml-expansion-fix2.rb before using
REXML.

    require "rexml-expansion-fix2"
    ...
    doc = REXML::Document.new(str)
    ...

If you have a Rails application, copy rexml-expansion-fix2.rb into a
directory on the load path (such as RAILS\_ROOT/lib/), and put the
following line into config/environment.rb.

    require "rexml-expansion-fix2"

If your application is Rails 2.1 or later, you can simply copy
rexml-expansion-fix2.rb to RAILS\_ROOT/config/initializers and it will
be required automatically.

By default, XML entity expansion limit is 10000. You can change it by
changing REXML::Document.entity\_expansion\_limit. e.g.

    REXML::Document.entity_expansion_limit = 1000

This fix will be made available as a gem and used by future versions of
rails, but users should take corrective action immediately.

## 

Credit to Luka Treiber and Mitja Kolsek of ACROS Security for disclosing
the problem to Ruby and Rails Security Teams.

Credit to Michael Koziarski of Rails Core Team for creating the monkey
patch to fix the vulnerability.

## 

* 2008-08-29 18:46 +09:00 fixed the summary not to mislead that this
  vulnerability is Rails specific.
* 2008-11-09 12:40 +09:00 fixed [a bug of the monkey patch][2].



[1]: http://www.ruby-lang.org/security/20080823rexml/rexml-expansion-fix2.rb 
[2]: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=502535 
